@@ -10,5 +10,8 @@ class ResultOptions(BaseModel):
     #: send message only when stealth mode is enabled.
     stealth_mode: bool = False
 
+    #: don't show next user messages in chat
+    silent_response: bool = False
+
     #: message options for configuring notifications.
     notification_opts: NotificationOptions = NotificationOptions()
